@@ -1,4 +1,3 @@
-from __future__ import absolute_import
 from ._version import get_versions
 __version__ = get_versions()['version']
 del get_versions
@@ -8,10 +7,14 @@ client_protocol_hostname, protocol, server,
 register, login, refresh, api_token, verify_token,
 store_token_creds_in_memory,
 name, description,
-bind, edges, nodes, graph, settings, 
+bind, style, addStyle, edges, nodes, graph, settings,
+encode_point_color, encode_point_size, encode_point_icon,
+encode_edge_color, encode_edge_icon,
+encode_point_badge, encode_edge_color,
 hypergraph, 
 bolt, cypher,
 tigergraph, gsql, gsql_endpoint,
 nodexl,
-ArrowUploader
+ArrowUploader,
+PyGraphistry
 )
\ No newline at end of file
