@@ -1,13 +1,4 @@
 """Top-level import of class PyGraphistry as "Graphistry". Used to connect to the Graphistry server and then create a base plotter."""
-
-from __future__ import absolute_import
-from __future__ import print_function
-from future import standard_library
-standard_library.install_aliases()
-from builtins import bytes, object, str
-from past.utils import old_div
-from past.builtins import basestring
-
 import calendar, gzip, io, json, os, numpy, pandas, requests, sched, sys, time, warnings
 
 from datetime import datetime
@@ -17,6 +8,7 @@ from .arrow_uploader import ArrowUploader
 
 from . import util
 from . import bolt_util
+from .plotter import Plotter
 
 import logging
 logger = logging.getLogger(__name__)
@@ -32,7 +24,8 @@ EnvVarNames = {
     'hostname': 'GRAPHISTRY_HOSTNAME',
     'protocol': 'GRAPHISTRY_PROTOCOL',
     'client_protocol_hostname': 'GRAPHISTRY_CLIENT_PROTOCOL_HOSTNAME',
-    'certificate_validation': 'GRAPHISTRY_CERTIFICATE_VALIDATION'
+    'certificate_validation': 'GRAPHISTRY_CERTIFICATE_VALIDATION',
+    'store_token_creds_in_memory': 'GRAPHISTRY_STORE_CREDS_IN_MEMORY'
 }
 
 config_paths = [
@@ -51,7 +44,7 @@ default_config = {
     'protocol': 'https',
     'client_protocol_hostname': None,
     'certificate_validation': True,
-    'store_token_creds_in_memory': False
+    'store_token_creds_in_memory': True
 }
 
 
@@ -62,7 +55,7 @@ def _get_initial_config():
             with open(path) as config_file:
                 config.update(json.load(config_file))
         except ValueError as e:
-            util.warn('Syntax error in %s, skipping. (%s)' % (path, e.message))
+            util.warn('Syntax error in %s, skipping. (%s)' % (path, e))
             pass
         except IOError:
             pass
@@ -117,6 +110,7 @@ class PyGraphistry(object):
         if PyGraphistry._config['store_token_creds_in_memory']:
             PyGraphistry.relogin = lambda: PyGraphistry.login(username, password, fail_silent)
 
+        PyGraphistry._is_authenticated = False
         token = ArrowUploader(
             server_base_path=PyGraphistry.protocol() + '://' + PyGraphistry.server(),
             certificate_validation=PyGraphistry.certificate_validation())\
@@ -124,9 +118,6 @@ class PyGraphistry(object):
         PyGraphistry.api_token(token)
         PyGraphistry._is_authenticated = True
 
-        #starts auth loop
-        PyGraphistry.authenticate()
-
         return PyGraphistry.api_token()
 
     @staticmethod
@@ -195,7 +186,8 @@ class PyGraphistry(object):
         if value is None:
             return PyGraphistry._config['store_token_creds_in_memory']
         else:
-            PyGraphistry._config['store_token_creds_in_memory'] = value
+            v = bool(strtobool(value)) if isinstance(value, str) else value
+            PyGraphistry._config['store_token_creds_in_memory'] = v
 
     @staticmethod
     def client_protocol_hostname(value=None):
@@ -281,7 +273,7 @@ class PyGraphistry(object):
             return PyGraphistry._config['certificate_validation']
 
         # setter
-        v = bool(strtobool(value)) if isinstance(value, basestring) else value
+        v = bool(strtobool(value)) if isinstance(value, str) else value
         if v == False:
             requests.packages.urllib3.disable_warnings()
         PyGraphistry._config['certificate_validation'] = v
@@ -320,8 +312,8 @@ class PyGraphistry(object):
         :type protocol: Optional string.
         :param token_refresh_ms: Ignored for now; JWT token auto-refreshed on plot() calls.
         :type token_refresh_ms:
-        :param store_token_creds_in_memory: Store username/password in-memory for JWT token refreshes. Unsafe; not recommended.
-        :type store_token_creds_in_memory: Optional bool.
+        :param store_token_creds_in_memory: Store username/password in-memory for JWT token refreshes (Token-originated have a hard limit, so always-on requires creds somewhere)
+        :type store_token_creds_in_memory: Optional bool. Default-on.
         :param client_protocol_hostname: Override protocol and host shown in browser. Defaults to protocol/server or envvar GRAPHISTRY_CLIENT_PROTOCOL_HOSTNAME.
         :type client_protocol_hostname: Optional string.
         :returns: None.
@@ -355,9 +347,7 @@ class PyGraphistry(object):
         PyGraphistry.protocol(protocol)
         PyGraphistry.client_protocol_hostname(client_protocol_hostname)
         PyGraphistry.certificate_validation(certificate_validation)
-
-        if not (store_token_creds_in_memory is None):
-            PyGraphistry.store_token_creds_in_memory(bool(store_token_creds_in_memory))
+        PyGraphistry.store_token_creds_in_memory(store_token_creds_in_memory)
         if not (username is None) and not (password is None):
             PyGraphistry.login(username, password)
         PyGraphistry.api_token(token or PyGraphistry._config['api_token'])
@@ -447,8 +437,7 @@ class PyGraphistry(object):
 
                     g = graphistry.bolt(driver)
         """
-        from . import plotter
-        return plotter.Plotter().bolt(driver)
+        return Plotter().bolt(driver)
 
 
     @staticmethod
@@ -466,8 +455,7 @@ class PyGraphistry(object):
                     import graphistry
                     g = graphistry.bolt({ query='MATCH (a)-[r:PAYMENT]->(b) WHERE r.USD > 7000 AND r.USD < 10000 RETURN r ORDER BY r.USD DESC', params={ "AccountId": 10 })
         """
-        from . import plotter
-        return plotter.Plotter().cypher(query, params)
+        return Plotter().cypher(query, params)
 
 
     @staticmethod
@@ -484,8 +472,7 @@ class PyGraphistry(object):
         if not (engine is None):
             print('WARNING: Engine currently ignored, please contact if critical')
 
-        from . import plotter
-        return plotter.Plotter().nodexl(xls_or_url, source, engine, verbose)
+        return Plotter().nodexl(xls_or_url, source, engine, verbose)
 
 
     @staticmethod
@@ -495,8 +482,7 @@ class PyGraphistry(object):
         :param name: Upload name
         :type name: str"""
 
-        from . import plotter
-        return plotter.Plotter().name(name)
+        return Plotter().name(name)
 
     @staticmethod
     def description(description):
@@ -505,10 +491,347 @@ class PyGraphistry(object):
         :param description: Upload description
         :type description: str"""
 
-        from . import plotter
-        return plotter.Plotter().description(description)
+        return Plotter().description(description)
 
 
+    @staticmethod
+    def addStyle(bg=None, fg=None, logo=None, page=None):
+        """Creates a base plotter with some style settings.
+        
+        For parameters, see ``plotter.addStyle``.
+
+        :returns: Plotter.
+        :rtype: Plotter.
+
+        **Example**
+
+            ::
+
+                import graphistry
+                graphistry.addStyle(bg={'color': 'black'})
+        """
+
+        return Plotter().addStyle(bg=bg, fg=fg, logo=logo, page=page)
+
+
+
+    @staticmethod
+    def style(bg=None, fg=None, logo=None, page=None):
+        """Creates a base plotter with some style settings.
+        
+        For parameters, see ``plotter.style``.
+
+        :returns: Plotter.
+        :rtype: Plotter.
+
+        **Example**
+
+            ::
+
+                import graphistry
+                graphistry.style(bg={'color': 'black'})
+        """
+
+        return Plotter().style(bg=bg, fg=fg, logo=logo, page=page)
+
+
+
+
+    @staticmethod
+    def encode_point_color(column,
+            palette=None, as_categorical=None, as_continuous=None, categorical_mapping=None, default_mapping=None,
+            for_default=True, for_current=False):
+        """Set point color with more control than bind()
+
+        :param column: Data column name
+        :type column: str.
+
+        :param palette: Optional list of color-like strings. Ex: ["black, "#FF0", "rgb(255,255,255)" ]. Used as a gradient for continuous and round-robin for categorical.
+        :type palette: list, optional.
+
+        :param as_categorical: Interpret column values as categorical. Ex: Uses palette via round-robin when more values than palette entries.
+        :type as_categorical: bool, optional.
+
+        :param as_continuous: Interpret column values as continuous. Ex: Uses palette for an interpolation gradient when more values than palette entries.
+        :type as_continuous: bool, optional.
+
+        :param categorical_mapping: Mapping from column values to color-like strings. Ex: {"car": "red", "truck": #000"}
+        :type categorical_mapping: dict, optional.
+
+        :param default_mapping: Augment categorical_mapping with mapping for values not in categorical_mapping. Ex: default_mapping="gray".
+        :type default_mapping: str, optional.
+
+        :param for_default: Use encoding for when no user override is set. Default on.
+        :type for_default: bool, optional.
+
+        :param for_current: Use encoding as currently active. Clearing the active encoding resets it to default, which may be different. Default on.
+        :type for_current: bool, optional.
+
+        :returns: Plotter.
+        :rtype: Plotter.
+
+        **Example: Set a palette-valued column for the color, same as bind(point_color='my_column')**
+            ::
+                g2a = g.encode_point_color('my_int32_palette_column')
+                g2b = g.encode_point_color('my_int64_rgb_column')
+
+        **Example: Set a cold-to-hot gradient of along the spectrum blue, yellow, red**
+            ::
+                g2 = g.encode_point_color('my_numeric_col', palette=["blue", "yellow", "red"], as_continuous=True)
+
+        **Example: Round-robin sample from 5 colors in hex format**
+            ::
+                g2 = g.encode_point_color('my_distinctly_valued_col', palette=["#000", "#00F", "#0F0", "#0FF", "#FFF"], as_categorical=True)
+
+        **Example: Map specific values to specific colors, including with a default**
+            ::
+                g2a = g.encode_point_color('brands', categorical_mapping={'toyota': 'red', 'ford': 'blue'})
+                g2a = g.encode_point_color('brands', categorical_mapping={'toyota': 'red', 'ford': 'blue'}, default_mapping='gray')
+
+        """
+
+        return Plotter().encode_point_color(
+            column=column, palette=palette, as_categorical=as_categorical, as_continuous=as_continuous,
+            categorical_mapping=categorical_mapping, default_mapping=default_mapping,
+            for_default=for_default, for_current=for_current)
+
+
+    @staticmethod
+    def encode_edge_color(column,
+            palette=None, as_categorical=None, as_continuous=None, categorical_mapping=None, default_mapping=None,
+            for_default=True, for_current=False):
+        """Set edge color with more control than bind()
+
+        :param column: Data column name
+        :type column: str.
+
+        :param palette: Optional list of color-like strings. Ex: ["black, "#FF0", "rgb(255,255,255)" ]. Used as a gradient for continuous and round-robin for categorical.
+        :type palette: list, optional.
+
+        :param as_categorical: Interpret column values as categorical. Ex: Uses palette via round-robin when more values than palette entries.
+        :type as_categorical: bool, optional.
+
+        :param as_continuous: Interpret column values as continuous. Ex: Uses palette for an interpolation gradient when more values than palette entries.
+        :type as_continuous: bool, optional.
+
+        :param categorical_mapping: Mapping from column values to color-like strings. Ex: {"car": "red", "truck": #000"}
+        :type categorical_mapping: dict, optional.
+
+        :param default_mapping: Augment categorical_mapping with mapping for values not in categorical_mapping. Ex: default_mapping="gray".
+        :type default_mapping: str, optional.
+
+        :param for_default: Use encoding for when no user override is set. Default on.
+        :type for_default: bool, optional.
+
+        :param for_current: Use encoding as currently active. Clearing the active encoding resets it to default, which may be different. Default on.
+        :type for_current: bool, optional.
+
+        :returns: Plotter.
+        :rtype: Plotter.
+
+        **Example: See encode_point_color**
+        """
+
+        return Plotter().encode_edge_color(
+            column=column, palette=palette, as_categorical=as_categorical, as_continuous=as_continuous,
+            categorical_mapping=categorical_mapping, default_mapping=default_mapping,
+            for_default=for_default, for_current=for_current)
+
+    @staticmethod
+    def encode_point_size(column,
+            categorical_mapping=None, default_mapping=None,
+            for_default=True, for_current=False):
+        """Set point size with more control than bind()
+
+        :param column: Data column name
+        :type column: str.
+
+        :param categorical_mapping: Mapping from column values to numbers. Ex: {"car": 100, "truck": 200}
+        :type categorical_mapping: dict, optional.
+
+        :param default_mapping: Augment categorical_mapping with mapping for values not in categorical_mapping. Ex: default_mapping=50.
+        :type default_mapping: numeric, optional.
+
+        :param for_default: Use encoding for when no user override is set. Default on.
+        :type for_default: bool, optional.
+
+        :param for_current: Use encoding as currently active. Clearing the active encoding resets it to default, which may be different. Default on.
+        :type for_current: bool, optional.
+
+        :returns: Plotter.
+        :rtype: Plotter.
+
+        **Example: Set a numerically-valued column for the size, same as bind(point_size='my_column')**
+            ::
+                g2a = g.encode_point_size('my_numeric_column')
+
+        **Example: Map specific values to specific colors, including with a default**
+            ::
+                g2a = g.encode_point_size('brands', categorical_mapping={'toyota': 100, 'ford': 200})
+                g2b = g.encode_point_size('brands', categorical_mapping={'toyota': 100, 'ford': 200}, default_mapping=50)
+
+        """
+
+        return Plotter().encode_point_size(column=column,
+            categorical_mapping=categorical_mapping, default_mapping=default_mapping,
+            for_default=for_default, for_current=for_current)
+
+
+    @staticmethod
+    def encode_point_icon(column,
+            categorical_mapping=None, continuous_binning=None, default_mapping=None,
+            comparator=None,
+            for_default=True, for_current=False, as_text=False, blend_mode=None, style=None, border=None, shape=None):
+        """Set node icon with more control than bind(). Values from Font Awesome 4 such as "laptop": https://fontawesome.com/v4.7.0/icons/
+
+        :param column: Data column name
+        :type column: str.
+
+        :param categorical_mapping: Mapping from column values to icon name strings. Ex: {"toyota": 'car', "ford": 'truck'}
+        :type categorical_mapping: dict, optional.
+
+        :param default_mapping: Augment categorical_mapping with mapping for values not in categorical_mapping. Ex: default_mapping=50.
+        :type default_mapping: numeric, optional.
+
+        :param for_default: Use encoding for when no user override is set. Default on.
+        :type for_default: bool, optional.
+
+        :param for_current: Use encoding as currently active. Clearing the active encoding resets it to default, which may be different. Default on.
+        :type for_current: bool, optional.
+
+        :param as_text: Values should instead be treated as raw strings, instead of icons and images. (Default False.)
+        :type as_text: bool, optional.
+
+        :param blend_mode: CSS blend mode
+        :type blend_mode: str, optional.
+
+        :param style: CSS filter properties - opacity, saturation, luminosity, grayscale, and more
+        :type style: dict, optional
+
+        :param border: Border properties - 'width', 'color', and 'storke'
+        :type border: dict, optional
+
+        :returns: Plotter.
+        :rtype: Plotter.
+
+        **Example: Set a string column of icons for the point icons, same as bind(point_icon='my_column')**
+            ::
+                g2a = g.encode_point_icon('my_icons_column')
+
+        **Example: Map specific values to specific icons, including with a default**
+            ::
+                g2a = g.encode_point_icon('brands', categorical_mapping={'toyota': 'car', 'ford': 'truck'})
+                g2b = g.encode_point_icon('brands', categorical_mapping={'toyota': 'car', 'ford': 'truck'}, default_mapping='question')
+
+        **Example: Map countries to abbreviations**
+            ::
+                g2b = g.encode_point_icon('country_abbrev', as_text=True)
+                g2b = g.encode_point_icon('country', as_text=True, categorical_mapping={'England': 'UK', 'America': 'US'}, default_mapping='')
+
+        **Example: Border**
+            ::
+                g2b = g.encode_point_icon('country', border={'width': 3, color: 'black', 'stroke': 'dashed'}, 'categorical_mapping={'England': 'UK', 'America': 'US'})
+
+        """
+
+        return Plotter().encode_point_icon(column=column,
+            categorical_mapping=categorical_mapping, continuous_binning=continuous_binning, default_mapping=default_mapping,
+            comparator=comparator,
+            for_default=for_default, for_current=for_current,
+            as_text=as_text, blend_mode=blend_mode, style=style, border=border, shape=shape)
+
+
+    @staticmethod
+    def encode_edge_icon(column,
+            categorical_mapping=None, continuous_binning=None, default_mapping=None,
+            comparator=None,
+            for_default=True, for_current=False,
+            as_text=False, blend_mode=None, style=None, border=None, shape=None):
+        """Set edge icon with more control than bind(). Values from Font Awesome 4 such as "laptop": https://fontawesome.com/v4.7.0/icons/
+
+        :param column: Data column name
+        :type column: str.
+
+        :param categorical_mapping: Mapping from column values to icon name strings. Ex: {"toyota": 'car', "ford": 'truck'}
+        :type categorical_mapping: dict, optional.
+
+        :param default_mapping: Augment categorical_mapping with mapping for values not in categorical_mapping. Ex: default_mapping=50.
+        :type default_mapping: numeric, optional.
+
+        :param for_default: Use encoding for when no user override is set. Default on.
+        :type for_default: bool, optional.
+
+        :param for_current: Use encoding as currently active. Clearing the active encoding resets it to default, which may be different. Default on.
+        :type for_current: bool, optional.
+
+        :param as_text: Values should instead be treated as raw strings, instead of icons and images. (Default False.)
+        :type as_text: bool, optional.
+
+        :param blend_mode: CSS blend mode
+        :type blend_mode: str, optional.
+
+        :param style: CSS filter properties - opacity, saturation, luminosity, grayscale, and more
+        :type style: dict, optional
+
+        :param border: Border properties - 'width', 'color', and 'storke'
+        :type border: dict, optional
+
+        :returns: Plotter.
+        :rtype: Plotter.
+
+        **Example: Set a string column of icons for the edge icons, same as bind(edge_icon='my_column')**
+            ::
+                g2a = g.encode_edge_icon('my_icons_column')
+
+        **Example: Map specific values to specific icons, including with a default**
+            ::
+                g2a = g.encode_edge_icon('brands', categorical_mapping={'toyota': 'car', 'ford': 'truck'})
+                g2b = g.encode_edge_icon('brands', categorical_mapping={'toyota': 'car', 'ford': 'truck'}, default_mapping='question')
+
+        **Example: Map countries to abbreviations**
+            ::
+                g2a = g.encode_edge_icon('country_abbrev', as_text=True)
+                g2b = g.encode_edge_icon('country', categorical_mapping={'England': 'UK', 'America': 'US'}, default_mapping='')
+
+        **Example: Border**
+            ::
+                g2b = g.encode_edge_icon('country', border={'width': 3, color: 'black', 'stroke': 'dashed'}, 'categorical_mapping={'England': 'UK', 'America': 'US'})
+
+        """
+
+        return Plotter().encode_edge_icon(column=column,
+            categorical_mapping=categorical_mapping, continuous_binning=continuous_binning, default_mapping=default_mapping,
+            comparator=comparator,
+            for_default=for_default, for_current=for_current,
+            as_text=as_text, blend_mode=blend_mode, style=style, border=border, shape=shape)
+
+
+    @staticmethod
+    def encode_edge_badge(column, position='TopRight',
+            categorical_mapping=None, continuous_binning=None, default_mapping=None, comparator=None,
+            color=None, bg=None, fg=None,
+            for_current=False, for_default=True,
+            as_text=None, blend_mode=None, style=None, border=None, shape=None):
+
+        return Plotter().encode_edge_badge(column=column,
+            categorical_mapping=categorical_mapping, continuous_binning=continuous_binning, default_mapping=default_mapping, comparator=comparator,
+            color=color, bg=bg, fg=fg,
+            for_current=for_current, for_default=for_default,
+            as_text=as_text, blend_mode=blend_mode, style=style, border=border, shape=shape)
+
+    @staticmethod
+    def encode_point_badge(column, position='TopRight',
+            categorical_mapping=None, continuous_binning=None, default_mapping=None, comparator=None,
+            color=None, bg=None, fg=None,
+            for_current=False, for_default=True,
+            as_text=None, blend_mode=None, style=None, border=None, shape=None):
+
+        return Plotter().encode_point_badge(column=column,
+            categorical_mapping=categorical_mapping, continuous_binning=continuous_binning, default_mapping=default_mapping, comparator=comparator,
+            color=color, bg=bg, fg=fg,
+            for_current=for_current, for_default=for_default,
+            as_text=as_text, blend_mode=blend_mode, style=style, border=border, shape=shape)
+
     @staticmethod
     def bind(node=None, source=None, destination=None,
              edge_title=None, edge_label=None, edge_color=None, edge_weight=None, edge_icon=None, edge_size=None, edge_opacity=None,
@@ -531,10 +854,7 @@ class PyGraphistry(object):
 
         """
 
-
-
-        from . import plotter
-        return plotter.Plotter().bind(source=source, destination=destination, node=node, \
+        return Plotter().bind(source=source, destination=destination, node=node, \
                               edge_title=edge_title, edge_label=edge_label, edge_color=edge_color, 
                               edge_size=edge_size, edge_weight=edge_weight, edge_icon=edge_icon, edge_opacity=edge_opacity,
                               edge_source_color=edge_source_color, edge_destination_color=edge_destination_color,
@@ -583,8 +903,8 @@ class PyGraphistry(object):
                     tg = graphistry.tigergraph(protocol='https', server='acme.com', db='my_db', user='alice', pwd='tigergraph2')                    
 
         """
-        from . import plotter
-        return plotter.Plotter().tigergraph(protocol, server, web_port, api_port, db, user, pwd, verbose)
+
+        return Plotter().tigergraph(protocol, server, web_port, api_port, db, user, pwd, verbose)
 
 
     @staticmethod
@@ -627,8 +947,8 @@ class PyGraphistry(object):
                     (nodes_df, edges_df) = (out._nodes, out._edges)
 
         """
-        from . import plotter
-        return plotter.Plotter().gsql_endpoint(method_name, args, bindings, db, dry_run)
+
+        return Plotter().gsql_endpoint(method_name, args, bindings, db, dry_run)
 
 
 
@@ -701,33 +1021,96 @@ INTERPRET QUERY () FOR GRAPH Storage {
   }
                     \"\"\", {'edges': 'my_edge_list'}).plot()
         """
-        from . import plotter
-        return plotter.Plotter().gsql(query, bindings, dry_run)
+
+        return Plotter().gsql(query, bindings, dry_run)
 
 
 
     @staticmethod
-    def nodes(nodes):
-        from . import plotter
-        return plotter.Plotter().nodes(nodes)
+    def nodes(nodes, node=None):
+        """Specify the set of nodes and associated data.
+
+        Must include any nodes referenced in the edge list.
+
+        :param nodes: Nodes and their attributes.
+        :type point_size: Pandas dataframe
+
+        :returns: Plotter.
+        :rtype: Plotter.
+
+        **Example**
+            ::
+
+                import graphistry
+
+                es = pandas.DataFrame({'src': [0,1,2], 'dst': [1,2,0]})
+                g = graphistry
+                    .bind(source='src', destination='dst')
+                    .edges(es)
+
+                vs = pandas.DataFrame({'v': [0,1,2], 'lbl': ['a', 'b', 'c']})
+                g = g.bind(node='v').nodes(vs)
+
+                g.plot()
+
+        **Example**
+            ::
+
+                import graphistry
+
+                es = pandas.DataFrame({'src': [0,1,2], 'dst': [1,2,0]})
+                g = graphistry.edges(es, 'src', 'dst')
+
+                vs = pandas.DataFrame({'v': [0,1,2], 'lbl': ['a', 'b', 'c']})
+                g = g.nodes(vs, 'v)
+
+                g.plot()
+        """
+        return Plotter().nodes(nodes, node)
 
 
     @staticmethod
-    def edges(edges):
-        from . import plotter
-        return plotter.Plotter().edges(edges)
+    def edges(edges, source=None, destination=None):
+        """Specify edge list data and associated edge attribute values.
+
+        :param edges: Edges and their attributes.
+        :type point_size: Pandas dataframe, NetworkX graph, or IGraph graph.
+
+        :returns: Plotter.
+        :rtype: Plotter.
+
+        **Example**
+            ::
+
+                import graphistry
+                df = pandas.DataFrame({'src': [0,1,2], 'dst': [1,2,0]})
+                graphistry
+                    .bind(source='src', destination='dst')
+                    .edges(df)
+                    .plot()
+
+        **Example**
+            ::
+                import graphistry
+                df = pandas.DataFrame({'src': [0,1,2], 'dst': [1,2,0]})
+                graphistry
+                    .edges(df, 'src', 'dst')
+                    .plot()
+
+        """
+        return Plotter().edges(edges, source, destination)
 
 
     @staticmethod
     def graph(ig):
-        from . import plotter
-        return plotter.Plotter().graph(ig)
+
+        return Plotter().graph(ig)
 
 
     @staticmethod
     def settings(height=None, url_params={}, render=None):
-        from . import plotter
-        return plotter.Plotter().settings(height, url_params, render)
+
+        return Plotter().settings(height, url_params, render)
 
 
     @staticmethod
@@ -788,12 +1171,10 @@ INTERPRET QUERY () FOR GRAPH Storage {
         else:
             raise ValueError('Unknown mode:', mode)
 
-        size = old_div(len(out_file.getvalue()), 1024)
-        if size >= 5 * 1024:
-            print('Uploading %d kB. This may take a while...' % size)
+        kb_size = len(out_file.getvalue()) // 1024
+        if kb_size >= 5 * 1024:
+            print('Uploading %d kB. This may take a while...' % kb_size)
             sys.stdout.flush()
-        elif size > 50 * 1024:
-            util.error('Dataset is too large (%d kB)!' % size)
 
         return out_file
 
@@ -906,6 +1287,15 @@ refresh = PyGraphistry.refresh
 api_token = PyGraphistry.api_token
 verify_token = PyGraphistry.verify_token
 bind = PyGraphistry.bind
+addStyle = PyGraphistry.addStyle
+style = PyGraphistry.style
+encode_point_color = PyGraphistry.encode_point_color
+encode_edge_color = PyGraphistry.encode_edge_color
+encode_point_size = PyGraphistry.encode_point_size
+encode_point_icon = PyGraphistry.encode_point_icon
+encode_edge_icon = PyGraphistry.encode_edge_icon
+encode_point_badge = PyGraphistry.encode_point_badge
+encode_edge_badge = PyGraphistry.encode_edge_badge
 name = PyGraphistry.name
 description = PyGraphistry.description
 edges = PyGraphistry.edges
